from django.db import models
from django.contrib.contenttypes.models import ContentType
from django.contrib.contenttypes.fields import GenericForeignKey


# Create your models here.

class Tag(models.Model):
    label = models.CharField(max_length=255)
    type = models.CharField(max_length=255, default=None, null=True, blank=True)

    def __str__(self) -> str:
        return self.label



class TaggedItem(models.Model):
    """
        This keeps track of the generic items that are tagged and when they were tagged.

        The time is important because when a profile is tagged 
        Public and then is changed to -> Private all information past that point is not going to be shared.
    
    """
    tag = models.ForeignKey(Tag, on_delete=models.CASCADE)
    content_type = models.ForeignKey(ContentType, on_delete=models.CASCADE)
    object_id = models.PositiveIntegerField()
    content_object = GenericForeignKey()
    tagged = models.DateTimeField(auto_now_add=True)
